@@ -21,11 +21,42 @@
 #'
 refresh_coronavirus_jhu <- function(){
   df <- NULL
+
+
+  year_start <- 2020
+  year_end <- as.numeric(format(Sys.Date(), "%Y"))
+
+
+
   tryCatch(
-    df <- readr::read_csv(file = "https://raw.githubusercontent.com/RamiKrispin/coronavirus/master/csv/coronavirus.csv",
-                          col_types = readr::cols(date = readr::col_date(format = "%Y-%m-%d"),
-                                           cases = readr::col_number(),
-                                           continent_code = readr::col_character())),
+    df <- lapply(year_start:year_end, function(i){
+      cat(paste0("\033[4;", 32, "m","Loading ", i, " data","\033[0m","\n"))
+      url <- paste("https://raw.githubusercontent.com/RamiKrispin/coronavirus/main/csv/coronavirus_",
+                   i,
+                   ".csv",
+                   sep = "")
+      temp <- readr::read_csv(url,
+                            col_types = readr::cols(
+                              date = readr::col_date(format = ""),
+                              province = readr::col_character(),
+                              country = readr::col_character(),
+                              lat = readr::col_double(),
+                              long = readr::col_double(),
+                              type = readr::col_character(),
+                              cases = readr::col_double(),
+                              uid = readr::col_double(),
+                              iso2 = readr::col_character(),
+                              iso3 = readr::col_character(),
+                              code3 = readr::col_double(),
+                              combined_key = readr::col_character(),
+                              population = readr::col_double(),
+                              continent_name = readr::col_character(),
+                              continent_code = readr::col_character()
+                            ))
+
+      return(temp)
+    }) |>
+      dplyr::bind_rows(),
     error = function(c) base::message(c)
     # warning = function(c) base::message(c),
     # message = function(c) base::message(c)
